@@ -54,9 +54,9 @@ class Plugin(Template):
         Loads the data from filename into the data_item_number.
         '''
         try:
-            with open(filename, 'r') as fh:
+            with open(filename, 'r', encoding='utf8') as fh:
                 header=fh.readlines()[:self.skip_rows]
-            load_array=np.loadtxt(filename, delimiter=self.delimiter,
+            load_array=np.loadtxt(filename, delimiter=self.delimiter, encoding='utf8',
                                   comments=self.comment, skiprows=self.skip_rows)
         except Exception as e:
             ShowWarningDialog(self.parent, 'Could not load the file: '+ \
