@@ -1,25 +1,28 @@
 #!/usr/bin/env python
 import logging
 import multiprocessing
-import threading
+from threading import Thread
 
 import appdirs
 import argparse
 import os
 import os.path
 import sys
-from logging import debug
+from logging import debug, getLogger
 
 from . import version
 from .core import custom_logging
 from .core.custom_logging import activate_excepthook, activate_logging, iprint, setup_system
 
 
-def start_interactive(args):
-    ''' Start genx in interactive mode (with the gui)
+config_path = os.path.abspath(appdirs.user_data_dir('GenX3', 'ArturGlavic'))
+os.environ['NUMBA_CACHE_DIR'] = os.path.join(config_path, 'numba_cache')
 
-    :param args:
-    :return:
+def start_interactive(args):
+    '''
+    Start genx in interactive mode (with the gui)
+
+    :param args: command line arguments evaluated with argparse.
     '''
     debug('enter start_interactive')
     activate_excepthook()
@@ -33,25 +36,20 @@ def start_interactive(args):
     from .gui import main_window
     if args.infile!='':
         debug('start GUI setup with file to load')
-        filename=args.infile
+        filename = os.path.abspath(args.infile)
+        #if getattr(sys, 'frozen', False):
+            # make sure the path is set to the program executable in a frozen binary
+            # this fixes unnecessery re-compiles of numba functions on Windows
+        #    os.chdir(os.path.dirname(os.path.abspath(sys.executable)))
+        #    debug(f'changed curdir to {os.path.abspath(os.path.curdir)}')
     else:
-        filename=None
+        filename = None
     debug('start GUI setup')
-    app= main_window.GenxApp(filename=filename, dpi_overwrite=args.dpi_overwrite)
+    app = main_window.GenxApp(filename=filename, dpi_overwrite=args.dpi_overwrite)
     debug('setup complete, start WX MainLoop')
     app.MainLoop()
     debug('leave start_interactive')
 
-def calc_errorbars(config, mod, opt):
-    error_values=[]
-    fom_error_bars_level=config.getfloat('solver', 'errorbar level')
-    n_elements=len(opt.start_guess)
-    for index in range(n_elements):
-        # calculate the error
-        # TODO: Check the error bar buisness again and how to treat Chi2
-        (error_low, error_high)=opt.calc_error_bar(index, fom_error_bars_level)
-        error_values.append('(%.3e, %.3e,)'%(error_low, error_high))
-    mod.parameters.set_error_pars(error_values)
 
 def create_simulated_data(args):
     """Function to create simulated data from the model and add it to data.y"""
@@ -62,8 +60,8 @@ def create_simulated_data(args):
     from scipy.stats import poisson
 
     io.config.load_default(os.path.join(os.path.dirname(os.path.abspath(__file__)), 'profiles', 'default.profile'))
-    ctrl=ModelController(DiffEv())
-    mod=ctrl.model
+    ctrl = ModelController(DiffEv())
+    mod = ctrl.model
 
     iprint("Loading file: %s "%args.infile)
     ctrl.load_file(args.infile)
@@ -74,15 +72,16 @@ def create_simulated_data(args):
     mod.simulate()
     iprint("Storing simualted data")
     for data_set in mod.data:
-        data_set.y_raw=poisson.rvs(data_set.y_sim)
-        data_set.y_command='y'
+        data_set.y_raw = poisson.rvs(data_set.y_sim)
+        data_set.y_command = 'y'
         data_set.run_y_command()
-        data_set.error_command='sqrt(where(y > 0, y, 1.0))'
+        data_set.error_command = 'sqrt(where(y > 0, y, 1.0))'
         data_set.run_error_command()
 
     iprint('Saving the model to %s'%args.outfile)
     ctrl.save_file(args.outfile)
 
+
 def extract_parameters(args):
     """Extracts the parameters to outfile"""
 
@@ -92,27 +91,30 @@ def extract_parameters(args):
 
     # Open the genx file
     io.config.load_default(os.path.join(os.path.dirname(os.path.abspath(__file__)), 'profiles', 'default.profile'))
-    ctrl=ModelController(DiffEv())
-    mod=ctrl.model
+    ctrl = ModelController(DiffEv())
+    mod = ctrl.model
 
     iprint("Loading file: %s "%args.infile)
     ctrl.load_file(args.infile)
     iprint("File loaded")
 
-    names, values=mod.parameters.get_sim_pars()
+    names, values = mod.parameters.get_sim_pars()
+    index_names = mod.parameters.get_names()
+    errors = [mod.parameters[index_names.index(ni)].error if mod.parameters.get_fit_state_by_name(ni)==1
+              else '-' for ni in names]
+    names = [ni if mod.parameters.get_fit_state_by_name(ni)!=1 else ni+'*' for ni in names]
 
-    if args.outfile=='':
-        fout=sys.stdout
-    else:
-        outfile=args.outfile
-        if os.path.isfile(outfile):
-            fout=open(outfile, 'a')
-        else:
-            fout=open(outfile, 'w')
+    paramstr = '\t'.join([name for name in names])+'\n'+ \
+               '\t'.join(['%f'%val for val in values])+'\n'
+    if args.error:
+        paramstr += '\t'.join([err for err in errors])+'\n'
+    if args.outfile!='':
+        iprint(f'Appending parameter values to file {args.outfile}')
+        with open(args.outfile, 'a') as fout:
             # Add header
-            fout.write('\t'.join([name for name in names])+'\n')
-    fout.write('\t'.join(['%f'%val for val in values])+'\n')
-    fout.close()
+            fout.write(paramstr)
+    iprint('\n'+paramstr)
+
 
 def modify_file(args):
     """Modify a GenX file given command line arguments"""
@@ -122,15 +124,15 @@ def modify_file(args):
 
     # Open the genx file
     io.config.load_default(os.path.join(os.path.dirname(os.path.abspath(__file__)), 'profiles', 'default.profile'))
-    ctrl=ModelController(DiffEv())
-    mod=ctrl.model
+    ctrl = ModelController(DiffEv())
+    mod = ctrl.model
 
     iprint("Loading file: %s "%args.infile)
     ctrl.load_file(args.infile)
     iprint("File loaded")
 
     if args.datafile:
-        datafile=os.path.abspath(args.datafile)
+        datafile = os.path.abspath(args.datafile)
         if 0>args.data_set or args.data_set>=len(mod.data):
             iprint("The selected data set does not exist - select one between 0 and %d"%(len(mod.data)-1))
             return
@@ -142,7 +144,7 @@ def modify_file(args):
             ctrl.save_file(args.outfile)
 
     elif args.save_datafile:
-        save_datafile=os.path.abspath(args.save_datafile)
+        save_datafile = os.path.abspath(args.save_datafile)
         iprint("Simualting..")
         mod.simulate()
         if 0>args.data_set or args.data_set>=len(mod.data):
@@ -151,109 +153,96 @@ def modify_file(args):
         iprint('Exporting data set %d into ASCII file %s'%(args.data_set, save_datafile))
         mod.data[args.data_set].save_file(save_datafile)
 
+
+def set_numba_single():
+    debug('Setting numba JIT compilation to single CPU')
+    os.environ['NUMBA_CACHE_DIR'] = os.path.join(config_path, 'single_cpu_numba_cache')
+
+    import numba
+    old_jit = numba.jit
+
+    def jit(*args, **opts):
+        opts['parallel'] = False
+        return old_jit(*args, **opts)
+
+    numba.jit = jit
+    numba.GENX_OVERWRITE_SINGLE = True
+    try:
+        numba.set_num_threads(1)
+    except AttributeError:
+        pass
+
+
+class InputThread(Thread):
+    def __init__(self):
+        Thread.__init__(self, daemon=True)
+        self.stop_fit = False
+
+    def run(self):
+        # concole input has to be queried differently for non-UNIX systems
+        if sys.platform.startswith('win'):
+            self.run_windows()
+        else:
+            self.run_unix()
+
+    def run_windows(self):
+        import msvcrt, time
+        while not self.stop_fit:
+            if msvcrt.kbhit():
+                debug('Key event received')
+                key = msvcrt.getwch()
+                if 'q' in key:
+                    self.stop_fit = True
+            time.sleep(0.1)
+
+    def run_unix(self):
+        import fcntl, selectors, time
+        # set sys.stdin non-blocking
+        orig_fl = fcntl.fcntl(sys.stdin, fcntl.F_GETFL)
+        fcntl.fcntl(sys.stdin, fcntl.F_SETFL, orig_fl | os.O_NONBLOCK)
+
+        m_selector = selectors.DefaultSelector()
+        m_selector.register(sys.stdin, selectors.EVENT_READ)
+        while True:
+            (k, evt)=m_selector.select()[0]
+            res = k.fileobj.read()
+            if 'q' in res:
+                self.stop_fit = True
+                break
+        m_selector.close()
+
 def start_fitting(args, rank=0):
-    """ Function to start fitting from the command line.
     """
-    # TODO: fix implementation of this
+    Function to start fitting from the command line.
+    """
     import time
-    from .diffev import DiffEv, DiffEvDefaultCallbacks
     from .model_control import ModelController
     from .core import config as io
+    from .core.console import calc_errorbars, setup_console
 
     # Open the genx file
     io.config.load_default(os.path.join(os.path.dirname(os.path.abspath(__file__)), 'profiles', 'default.profile'))
-    ctrl=ModelController(DiffEv())
-    mod=ctrl.model
-    opt:DiffEv=ctrl.optimizer
-    config=io.config
+    if not args.bumps:
+        from .diffev import DiffEv
+        ctrl = ModelController(DiffEv())
+        mod = ctrl.model
+        opt: DiffEv = ctrl.optimizer
+        set_optimiser_pars = set_diffev_pars
+    else:
+        from .bumps_optimizer import BumpsOptimizer
+        ctrl = ModelController(BumpsOptimizer())
+        mod = ctrl.model
+        opt: BumpsOptimizer = ctrl.optimizer
+        set_optimiser_pars = set_bumps_pars
 
     if rank==0:
+        setup_console(ctrl, args.error, args.outfile, use_curses=(args.use_curses and not args.mpi))
+
+    if (args.mpi or args.pr>0) and not args.disable_numba:
         try:
-            import curses
+            set_numba_single()
         except ImportError:
-            stdscr = None
-        else:
-            stdscr = curses.initscr()
-            curses.noecho()
-            curses.cbreak()
-            stdscr.clear()
-            _, width = stdscr.getmaxyx()
-            stdscr.addstr(9, width//2-22, 'Relative value and spread of fit parameters:')
-            stdscr.addstr(9, width-11, 'best/width')
-            stdscr.nodelay(True)
-            stdscr.refresh()
-            rl = logging.getLogger()
-            rl.handlers[0].setLevel(logging.ERROR+1)
-
-            class CursesHandler(logging.Handler):
-                message_history = []
-                max_messages = 8
-
-                def emit(self, record):
-                    try:
-                        msg = self.format(record)
-                        self.message_history+=msg.strip().splitlines()
-                        lkey = stdscr.getch()
-                        if lkey==ord('q'):
-                            self.message_history.append('"q" pressed, trying to stop fit.')
-                            opt.stop = True
-                        self.message_history = self.message_history[-self.max_messages:]
-                        for i, msg in enumerate(self.message_history):
-                            _, width = stdscr.getmaxyx()
-                            stdscr.addstr(i, 4, msg+' '*(width-4-len(msg)))
-                        stdscr.refresh()
-                    except (KeyboardInterrupt, SystemExit):
-                        raise
-                    except:
-                        self.handleError(record)
-
-            chandler = CursesHandler()
-            chandler.setLevel(logging.INFO)
-            rl.addHandler(chandler)
-        from numpy import array, arange
-
-        class CB(DiffEvDefaultCallbacks):
-            def autosave(self):
-                # print 'Updating the parameters'
-                mod.parameters.set_value_pars(opt.best_vec)
-                if args.error:
-                    iprint("Calculating error bars")
-                    calc_errorbars(io.config, mod, ctrl.optimizer)
-                if args.outfile:
-                    iprint("Saving to %s"%args.outfile)
-                    ctrl.save_file(args.outfile)
-
-            def parameter_output(self, param_info):
-                if stdscr:
-                    height, width = stdscr.getmaxyx()
-                    full_width=(width-16-12)
-                    pwidth=param_info.max_val-param_info.min_val
-                    pres=(param_info.values-param_info.min_val)/pwidth
-                    population=array(param_info.population)
-                    pmin=(population.min(axis=0)-param_info.min_val)/pwidth
-                    pmax=(population.max(axis=0)-param_info.min_val)/pwidth
-                    pwidth=pmax-pmin
-                    maxpar=height-10
-                    if maxpar<param_info.values.shape[0]:
-                        order=pwidth.argsort()[::-1]
-                    else:
-                        order=arange(param_info.values.shape[0])
-
-                    for i in range(min(param_info.values.shape[0], maxpar)):
-                        param_id=order[i]
-                        stdscr.hline(10+i, 16, ' ', full_width)
-                        stdscr.addstr(10+i, 1, 'Parameter %02i: ['%param_id)
-                        stdscr.addstr(10+i, width-12, '] %.2f/%.2f'%(pres[param_id], pwidth[param_id]))
-
-                        ppos=max(0.0, min(1.0, pres[param_id]))
-                        wstart=max(0.0, min(1.0, pmin[param_id]))
-                        wwidth=max(0.0, min(1.0-wstart, pwidth[param_id]))
-                        stdscr.hline(10+i, 16+int(full_width*wstart), '=', int(full_width*wwidth))
-                        stdscr.addstr(10+i, 16+int(full_width*ppos), '#')
-
-                    stdscr.refresh()
-
-        ctrl.set_callbacks(CB())
+            pass
 
     if rank==0:
         iprint('Loading model %s...'%args.infile)
@@ -267,10 +256,10 @@ def start_fitting(args, rank=0):
     mod.simulate()
 
     # Sets up the fitting ...
+    set_optimiser_pars(opt, args)
     if rank==0:
         iprint('Setting up the optimizer...')
         iprint(opt)
-    set_optimiser_pars(opt, args)
 
     if args.outfile and rank==0:
         iprint('Saving the initial model to %s'%args.outfile)
@@ -279,18 +268,26 @@ def start_fitting(args, rank=0):
     # To start the fitting
     if rank==0:
         iprint('Fitting starting...')
-        t1=time.time()
+        t1 = time.time()
     # print opt.use_mpi, opt.use_parallel_processing
     opt.start_fit(mod)
+    if rank==0:
+        inp = InputThread()
+        inp.start()
+    else:
+        class Inp(): stop_fit = False
+        inp = Inp()
     while opt.is_running():
         try:
             time.sleep(0.1)
+            if inp.stop_fit:
+                opt.stop = True
         except KeyboardInterrupt:
             iprint('KeyboardInterrupt, trying to stop fit.')
-            opt.stop=True
+            opt.stop = True
 
     if rank==0:
-        t2=time.time()
+        t2 = time.time()
         iprint('Fitting finished!')
         iprint('Time to fit: ', (t2-t1)/60., ' min')
 
@@ -301,24 +298,18 @@ def start_fitting(args, rank=0):
     if args.outfile and rank==0:
         if args.error:
             iprint('Calculating errorbars')
-            calc_errorbars(config, mod, opt)
+            calc_errorbars(mod, opt)
         iprint('Saving the fit to %s'%args.outfile)
-        opt.set_use_mpi(False)
+        # opt.set_use_mpi(False)
         ctrl.save_file(args.outfile)
 
     if rank==0:
         iprint('Fitting successfully completed')
 
-    if stdscr:
-        chandler.setLevel(logging.ERROR+1)
-        curses.nocbreak()
-        curses.echo()
-        curses.endwin()
-        rl.handlers[0].setLevel(logging.INFO)
-        print('\n'.join(chandler.message_history))
 
-def set_optimiser_pars(optimiser, args):
-    """ Sets the optimiser parameters from args
+def set_diffev_pars(optimiser, args):
+    """
+    Sets the optimiser parameters from args
     """
     if args.pr:
         optimiser.set_processes(args.pr)
@@ -344,39 +335,84 @@ def set_optimiser_pars(optimiser, args):
         optimiser.set_autosave_interval(args.asi)
         optimiser.set_use_autosave(True)
 
+    if args.var>=0:
+        optimiser.opt.min_parameter_spread = args.var
+
     if args.km>=0:
         optimiser.set_km(args.km)
-    # else:
-    #    print "km not set has to be bigger than 0"
 
     if args.kr>=0:
         optimiser.set_kr(args.kr)
-    # else:
-    #    print "kr not set has to be bigger than 0"
+
+
+def set_bumps_pars(optimiser, args):
+    if args.pr:
+        optimiser.opt.use_parallel_processing = True
+        optimiser.opt.parallel_processes = args.pr
+
+def compile_numba(cache_dir=None):
+    try:
+        # perform a compilation of numba functions with console feedback
+        import numba
+        from .models.lib.numba_integration import configure_numba
+        configure_numba()
+
+        import inspect
+
+        real_jit = numba.jit
+
+        class UpdateJit:
+            update_counter = 1
+
+            def __call__(self, *args, **opts):
+                if inspect.stack()[1][3]!='<lambda>':
+                    print(f'compiling numba functions {self.update_counter}/21')
+                    self.update_counter += 1
+                return real_jit(*args, **opts)
+
+        print('Starting to compile numba functions..')
+        numba.jit = UpdateJit()
+        print("paratt")
+        from .models.lib import paratt_numba
+        print('neutron')
+        from .models.lib import neutron_numba
+        print('instrument')
+        from .models.lib import instrument_numba
+        print('offspec')
+        from .models.lib import offspec
+        print('surface')
+        from .models.lib import surface_scattering
+        numba.jit = real_jit
+    except Exception as e:
+        print('An exception occured when trying to compile the numba functions:')
+        print(e)
+        return 1
+    return 0
 
 def main():
     multiprocessing.freeze_support()
+    multiprocessing.set_start_method('spawn')
     # Attempt to load mpi:
-    __mpi__=False
     try:
         from mpi4py import MPI
     except ImportError:
-        pass
+        rank = 0
+        __mpi__ = False
     else:
-        __mpi__=True
-        rank=MPI.COMM_WORLD.Get_rank()
+        __mpi__ = bool(MPI.COMM_WORLD.Get_size()>1)
+        rank = MPI.COMM_WORLD.Get_rank()
 
-    parser=argparse.ArgumentParser(description="GenX %s, fits data to a model."%version.__version__,
-                                   epilog="For support, manuals and bug reporting see http://genx.sf.net"
-                                   )
-    run_group=parser.add_mutually_exclusive_group()
+    parser = argparse.ArgumentParser(description="GenX %s, fits data to a model."%version.__version__,
+                                     epilog="For support, manuals and bug reporting see http://genx.sf.net"
+                                     )
+    run_group = parser.add_mutually_exclusive_group()
     run_group.add_argument('-r', '--run', action='store_true', help='run GenX fit (no gui)')
     if __mpi__:
         run_group.add_argument('--mpi', action='store_true', help='run GenX fit with mpi (no gui)')
     run_group.add_argument('-g', '--gen', action='store_true', help='generate data.y with poisson noise added')
     run_group.add_argument('--pars', action='store_true', help='extract the parameters from the infile')
     run_group.add_argument('--mod', action='store_true', help='modify the GenX file')
-    opt_group=parser.add_argument_group('optimization arguments')
+    opt_group = parser.add_argument_group('optimization arguments')
     opt_group.add_argument('--pr', type=int, default=0, help='Number of processes used in parallel fitting.')
     opt_group.add_argument('--cs', type=int, default=0, help='Chunk size used for parallel processing.')
     opt_group.add_argument('--mgen', type=int, default=0, help='Maximum number of generations that is used in a fit')
@@ -385,46 +421,74 @@ def main():
     opt_group.add_argument('--km', type=float, default=-1, help='Mutation constant (float 0 < km < 1)')
     opt_group.add_argument('--kr', type=float, default=-1, help='Cross over constant (float 0 < kr < 1)')
     opt_group.add_argument('-s', '--esave', action='store_true', help='Force save evals to gx file.')
-    opt_group.add_argument('-e', '--error', action='store_true', help='Calculate error bars before saving to file.')
-    data_group=parser.add_argument_group('data arguments')
+    opt_group.add_argument('-e', '--error', action='store_true', help='Calculate/export error bars.')
+    opt_group.add_argument('--var', type=float, default=-1,
+                           help='Minimum relative parameter variation to stop the fit (%%)')
+    opt_group.add_argument('--bumps', action='store_true',
+                           help='Use Bumps DREAM optimizer instead of GenX Differential Evolution')
+    data_group = parser.add_argument_group('data arguments')
     data_group.add_argument('-d', dest='data_set', type=int, default=0,
                             help='Active data set to act upon. Index starting at 0.')
     data_group.add_argument('--load', dest='datafile',
                             help='Load file into active data set. Index starting at 0.')
     data_group.add_argument('--export', dest='save_datafile',
                             help='Save active data set to file. Index starting at 0.')
-    data_group=parser.add_argument_group('startup options')
+    data_group = parser.add_argument_group('startup options')
     data_group.add_argument('-l', '--logfile', dest='logfile', default=None, type=str,
                             help='Output debug information to logfile.')
     data_group.add_argument('--debug', dest='debug', default=False, action="store_true",
                             help='Show additional debug information on console/logfile')
     data_group.add_argument('--dpi-scale', dest='dpi_overwrite', default=None, type=float,
                             help='Overwrite the detection of screen dpi scaling factor (=72/dpi)')
+    data_group.add_argument('--no-curses', dest='use_curses', default=True, action="store_false",
+                            help='Disable Curses interactive console interface for command line '
+                                 'fitting on UNIX systems.')
+    data_group.add_argument('--disable-nb', dest='disable_numba', default=False, action="store_true",
+                            help='Disable the use of numba JIT compiler')
+    data_group.add_argument('--nb1', dest='numba_single', default=False, action="store_true",
+                            help='Compile numba JIT functions without parallel computing support (use one core only). '
+                                 'Caching in this case is done in a different user directory.')
+    data_group.add_argument('--compile-nb', dest='compile_nb', default=False, action="store_true",
+                            help='Perform a first-/recompilation of the numba modules and exit')
 
-    parser.add_argument('infile', nargs='?', default='', help='The .gx or .hgx file to load or .ort file to use as basis for model')
+    parser.add_argument('infile', nargs='?', default='',
+                        help='The .gx or .hgx file to load or .ort file to use as basis for model')
     parser.add_argument('outfile', nargs='?', default='', help='The .gx  or hgx file to save into')
 
-    args=parser.parse_args()
+    args = parser.parse_args()
     if not __mpi__:
-        args.mpi=False
+        args.mpi = False
 
-    if args.run or args.mpi:
-        custom_logging.CONSOLE_LEVEL=logging.INFO
+    if args.run or args.mpi or args.pars or args.mod:
+        # make sure at least info-messages are shown (default is warning)
+        custom_logging.CONSOLE_LEVEL = min(logging.INFO, custom_logging.CONSOLE_LEVEL)
+    if rank>0:
+        custom_logging.CONSOLE_LEVEL = logging.WARNING
     setup_system()
 
     if args.logfile:
-        activate_logging(args.logfile)
+        if __mpi__:
+            lfbase, lfend = args.logfile.rsplit('.', 1)
+            activate_logging(f'{lfbase}_{rank:02}.{lfend}')
+        else:
+            activate_logging(args.logfile)
     debug("Arguments from parser: %s"%args)
     if not args.outfile:
-        args.outfile=args.infile
-    args.outfile=os.path.abspath(args.outfile)
+        args.outfile = args.infile
+    args.outfile = os.path.abspath(args.outfile)
     if args.infile:
-        args.infile=os.path.abspath(args.infile)
-    path=os.path.split(__file__)[0]
-    if os.path.abspath(path).endswith('.zip'):
-        os.chdir(os.path.split(path)[0])
-    else:
-        os.chdir(path)
+        args.infile = os.path.abspath(args.infile)
+
+    if args.disable_numba:
+        debug('disable numba')
+        # set numba flag
+        from genx.models import lib as modellib
+        modellib.USE_NUMBA = False
+    elif args.numba_single:
+        set_numba_single()
+    if args.compile_nb:
+        sys.exit(compile_numba())
+
 
     if args.run:
         start_fitting(args)
@@ -438,17 +502,18 @@ def main():
         modify_file(args)
     elif not args.run and not args.mpi:
         # Check if the application has been frozen
-        if hasattr(sys, "frozen") and True:
+        if getattr(sys, 'frozen', False):
             # Redirect all the output to log files
-            log_file_path=appdirs.user_log_dir('GenX3', 'ArturGlavic')
+            log_file_path = appdirs.user_log_dir('GenX3', 'ArturGlavic')
             # Create dir if not found
             if not os.path.exists(log_file_path):
                 os.makedirs(log_file_path)
             # print log_file_path
             # log_file_path = genx_gui._path + 'app_data/'
-            sys.stdout=open(log_file_path+'/genx.log', 'w')
-            sys.stderr=open(log_file_path+'/genx.log', 'w')
+            sys.stdout = open(log_file_path+'/genx_out.log', 'w')
+            sys.stderr = open(log_file_path+'/genx_err.log', 'w')
         start_interactive(args)
 
+
 if __name__=="__main__":
-    main()
\ No newline at end of file
+    main()
